# -*- coding: utf-8 -*-
from distutils.core import setup

package_dir = \
{'': 'src'}

packages = \
['env_time_converter', 'env_time_converter.helper']

package_data = \
{'': ['*'], 'env_time_converter': ['service/*']}

setup_kwargs = {
    'name': 'env-time-converter',
    'version': '0.1.6',
    'description': 'Easily convert differt time-range format to standard ones',
    'long_description': "![codecov](https://codecov.io/gh/massicer/Env-Time-Converter/branch/master/graph/badge.svg)\n\n# ENV Time Converter\n\nEasily manage different `time interval values`  and convert them to `milliseconds`. You can use this project to set a more readable info on your `.env`, `.yaml` or other configuration file.\n\n## Getting Started\n\nThese instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.\n\n### Prerequisites\n\n- [Poetry >=0.12](https://python-poetry.org)\n- Python ^3.5\n- Virtualenvwrapper or other virtualenv environment\n- make utility\n\n### Installing\n\nClone or download the repository\n\n```\ngit clone https://github.com/massicer/Env-Time-Converter.git\n```\n\nInstall project package\n```\nmake install\n```\n\nor without the make utility\n```\npoetry install\n```\n## Running the tests\n\nSimply type\n```\nmake test\n```\n## How To use\n\n### Available time formats\n| Unit Measure       | Allowed Sigles | default |\n| ------------- |:-----:| :-----:|\n| `milliseconds`  | `ms` , `milliseconds`, `sec`| `X`\n| `seconds`  | `seconds` , `s`, `sec`|\n| `minutes`  | `min` , `minute`, `minutes`|\n| `hours`  | `h` , `hours`, `hrs`, `hour`|\n| `days`  | `d` , `days`, `day`|\n| `years`  | `y` , `years`, `yrs`, `year`|\n\n\n\n - Simply using the `get_milliseconds_value_for_input` with the string value to convert. The below example use the number value `90` and the sigle `s`. \n \n    ```\n    from env_time_converter.service.convert_service import get_milliseconds_value_for_input\n    \n    # Assume this ENV is set by your .yaml or other configuration file.\n    os.environ['JOB_TIME'] = '90 seconds' \n\n    assert 9000 == get_milliseconds_value_for_input(os.environ['JOB_TIME'])\n    ```\n\n- When the time measure unit is missing the default value is `milliseconds`\n\n    ```\n    from env_time_converter.service.convert_service import get_milliseconds_value_for_input\n    \n    assert 90 == get_milliseconds_value_for_input('90')\n    ```\n\n\n## Authors\n\n* **[Massimiliano Ceriani](massimilianoceriani08@gmail.com)** - *Initial work* - [ENV Time Converter](https://github.com/massicer/Env-Time-Converter)\n\n## License\n\nThis project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details\n\n",
    'author': 'Massimiliano Ceriani',
    'author_email': 'massimiliano.ceriani08@gmail.com',
    'url': 'https://github.com/massicer/Env-Time-Converter',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
